==> ircii-2.8.36-pana.tar.gz: ircii-2.8/source/chelp.c <==

#include "irc.h"
#include "array.h"
#include "ircaux.h"
#include "chelp.h"
#include "output.h"
#include "vars.h"

static int read_file _((FILE *help_file));

void chelp _((char *command, char *args, char *subargs))
{
char *p, *new_comm = NULL;
static int first_time = 1;
int num = 0;
	if (!args || !*args)
	{
		bitchsay("Try /bhelp help");
		return;
	}
	if (first_time)
	{
		char *help_dir = NULL;
		FILE *help_file;
		malloc_sprintf(&help_dir, "%s/BitchX.help", get_string_var(CTOOLZ_DIR_VAR));
		if (!(help_file = uzfopen(&help_dir, ".")))
		{
			new_free(&help_dir);
			return;
		}
		new_free(&help_dir);
		first_time = 0;
		read_file(help_file);
		fclose(help_file);

	}	
	malloc_strcpy(&new_comm, args);
	p = &new_comm[strlen(new_comm)-1];
	while (*p && *p == ' ')
		*p-- = '\0';
	if ((p = strchr(new_comm, ' ')))
		*p = '$';

	if ((num = atoi(function_numitems(new_comm))))
	{
		int i = 0;
		char *subject = NULL;
		char *text;

		malloc_sprintf(&subject, "%s %d", new_comm, i);
		text = function_getitem(subject);
		put_it("\002%s\002: Help on Topic: \002%s\002", version, text);
		new_free(&text);

		for (i = 1; i < num; i++)
		{
			malloc_sprintf(&subject, "%s %d", new_comm, i);
			text = function_getitem(subject);
			put_it("%s", text);
			new_free(&text);
		}		
		new_free(&subject);
	} else
		bitchsay("No help on that");
	new_free(&new_comm);
}

static int read_file(FILE *help_file)
{
char line[BIG_BUFFER_SIZE + 1];
char *topic = NULL;
char *subject = NULL;
char *temp = NULL;
int item_number = 0;

	fgets(line, sizeof(line)-1, help_file);
	if (line)
		line[strlen(line)-1] = '\0';
	while (!feof(help_file))
	{
		if (*line && *line != ' ') /* we got a topic copy to topic */
		{
			char *p;
			item_number = 0;
			new_free(&topic); new_free(&subject);
			malloc_strcpy(&topic, line);
			if ((p = strchr(topic, ' ')))
				*p = '$';
			malloc_sprintf(&temp, "%s %d %s", topic, item_number++, line);
			function_setitem(temp);
			new_free(&temp);
			fgets(line, sizeof(line)-1, help_file);
			if (line)
			{
				line[strlen(line)-1] = '\0';
			}
		}
		else if (topic && *topic)
		{ /* we found the subject material */
			do {
				if (!line || (line && *line != ' '))
					break;
				malloc_sprintf(&temp, "%s %d %s", topic, item_number++, line);
				function_setitem(temp);
				fgets(line, sizeof(line)-1, help_file);
				if (line)
					line[strlen(line)-1] = '\0';
				new_free(&temp);
			} while (!feof(help_file));
		}
	}

	return 0;
}

==> ircii-2.8.45-pana.tar.gz: ircii-2.8/source/chelp.c <==

#include "irc.h"
#include "array.h"
#include "ircaux.h"
#include "chelp.h"
#include "output.h"
#include "vars.h"

static int read_file _((FILE *help_file));

void chelp _((char *command, char *args, char *subargs))
{
char *p, *new_comm = NULL;
static int first_time = 1;
int num = 0;
	if (!args || !*args)
	{
		bitchsay("Try /bhelp help");
		return;
	}
	if (first_time)
	{
		char *help_dir = NULL;
		FILE *help_file;
		malloc_sprintf(&help_dir, "%s/BitchX.help", get_string_var(CTOOLZ_DIR_VAR));
		if (!(help_file = uzfopen(&help_dir, ".")))
		{
			new_free(&help_dir);
			return;
		}
		new_free(&help_dir);
		first_time = 0;
		read_file(help_file);
		fclose(help_file);

	}	
	malloc_strcpy(&new_comm, args);
	p = &new_comm[strlen(new_comm)-1];
	while (*p && *p == ' ')
		*p-- = '\0';
	if ((p = strchr(new_comm, ' ')))
		*p = '$';

	if ((num = atoi(function_numitems(new_comm))))
	{
		int i = 0;
		char *subject = NULL;
		char *text;

		malloc_sprintf(&subject, "%s %d", new_comm, i);
		text = function_getitem(subject);
		put_it("\002%s\002: Help on Topic: \002%s\002", version, text);
		new_free(&text);

		for (i = 1; i < num; i++)
		{
			malloc_sprintf(&subject, "%s %d", new_comm, i);
			text = function_getitem(subject);
			put_it("%s", text);
			new_free(&text);
		}		
		new_free(&subject);
	} else
		bitchsay("No help on that");
	new_free(&new_comm);
}

static int read_file(FILE *help_file)
{
char line[BIG_BUFFER_SIZE + 1];
char *topic = NULL;
char *subject = NULL;
char *temp = NULL;
int item_number = 0;

	fgets(line, sizeof(line)-1, help_file);
	if (line)
		line[strlen(line)-1] = '\0';
	while (!feof(help_file))
	{
		if (!line || !*line)
		{
			fgets(line, sizeof(line)-1, help_file);
			continue;
		}
		else if (*line && *line != ' ') /* we got a topic copy to topic */
		{
			char *p;
			item_number = 0;
			new_free(&topic); new_free(&subject);
			malloc_strcpy(&topic, line);
			if ((p = strchr(topic, ' ')))
				*p = '$';
			malloc_sprintf(&temp, "%s %d %s", topic, item_number++, line);
			function_setitem(temp);
			new_free(&temp);
			fgets(line, sizeof(line)-1, help_file);
			if (line)
				line[strlen(line)-1] = '\0';
		}
		else if (topic && *topic)
		{ /* we found the subject material */
			do {
				if (!line || (line && *line != ' '))
					break;
				malloc_sprintf(&temp, "%s %d %s", topic, item_number++, line);
				function_setitem(temp);
				fgets(line, sizeof(line)-1, help_file);
				if (line)
					line[strlen(line)-1] = '\0';
				new_free(&temp);
			} while (!feof(help_file));
		}
	}

	return 0;
}
